"""Prefect command group integrations for the unified CLI."""

from __future__ import annotations

from cyclopts import App

prefect_app = App(name="prefect", help="Run Prefect server commands.")

prefect_app.command(
    "prefect.cli.server:start",
    name="start",
    help="Start a Prefect server instance.",
)

prefect_app.command(
    "prefect.cli.server:reset",
    name="reset-database",
    help="Reset the Prefect server database. This is a destructive operation, which will delete all flow run history from the Prefect server. Use with caution.",
)

prefect_app.command(
    "irsol_data_pipeline.cli.flows:flows_app",
    name="flows",
    help="List and serve Prefect flow groups.",
)

prefect_app.command(
    "irsol_data_pipeline.cli.variables:variables_app",
    name="variables",
    help="List and configure Prefect variables.",
)



"""Root Cyclopts application for idp."""

from __future__ import annotations

from cyclopts import App

from irsol_data_pipeline.version import __version__

app = App(
    name="idp",
    help=(
        "IRSOL Data Pipeline Operational CLI for Prefect server operations and inspecting runtime "
        "information."
    ),
    version=__version__,
)
app.register_install_completion_command()

app.command(
    "irsol_data_pipeline.cli.info:info",
    name="info",
    help="Show runtime and operational information.",
)
app.command(
    "irsol_data_pipeline.cli.prefect:prefect_app",
    name="prefect",
    help="Run Prefect server commands through the unified CLI.",
)


def main() -> None:
    """Run the root CLI application."""

    app()


if __name__ == "__main__":
    main()
